/* winxp-installer.c generated by valac 0.17.5.2-8558, the Vala compiler
 * generated from winxp-installer.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_FILE (boxes_unattended_file_get_type ())
#define BOXES_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFile))
#define BOXES_IS_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_FILE))
#define BOXES_UNATTENDED_FILE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFileIface))

typedef struct _BoxesUnattendedFile BoxesUnattendedFile;
typedef struct _BoxesUnattendedFileIface BoxesUnattendedFileIface;

#define TYPE_AVATAR_FORMAT (avatar_format_get_type ())
#define AVATAR_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AVATAR_FORMAT, AvatarFormat))
#define AVATAR_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AVATAR_FORMAT, AvatarFormatClass))
#define IS_AVATAR_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AVATAR_FORMAT))
#define IS_AVATAR_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AVATAR_FORMAT))
#define AVATAR_FORMAT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AVATAR_FORMAT, AvatarFormatClass))

typedef struct _AvatarFormat AvatarFormat;
typedef struct _AvatarFormatClass AvatarFormatClass;

#define BOXES_TYPE_WINDOWS_INSTALLER (boxes_windows_installer_get_type ())
#define BOXES_WINDOWS_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller))
#define BOXES_WINDOWS_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstallerClass))
#define BOXES_IS_WINDOWS_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WINDOWS_INSTALLER))
#define BOXES_IS_WINDOWS_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WINDOWS_INSTALLER))
#define BOXES_WINDOWS_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstallerClass))

typedef struct _BoxesWindowsInstaller BoxesWindowsInstaller;
typedef struct _BoxesWindowsInstallerClass BoxesWindowsInstallerClass;
typedef struct _BoxesWindowsInstallerPrivate BoxesWindowsInstallerPrivate;

#define BOXES_TYPE_WIN_XP_INSTALLER (boxes_win_xp_installer_get_type ())
#define BOXES_WIN_XP_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstaller))
#define BOXES_WIN_XP_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstallerClass))
#define BOXES_IS_WIN_XP_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIN_XP_INSTALLER))
#define BOXES_IS_WIN_XP_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIN_XP_INSTALLER))
#define BOXES_WIN_XP_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstallerClass))

typedef struct _BoxesWinXPInstaller BoxesWinXPInstaller;
typedef struct _BoxesWinXPInstallerClass BoxesWinXPInstallerClass;
typedef struct _BoxesWinXPInstallerPrivate BoxesWinXPInstallerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _avatar_format_unref0(var) ((var == NULL) ? NULL : (var = (avatar_format_unref (var), NULL)))

#define BOXES_TYPE_UNATTENDED_TEXT_FILE (boxes_unattended_text_file_get_type ())
#define BOXES_UNATTENDED_TEXT_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_TEXT_FILE, BoxesUnattendedTextFile))
#define BOXES_UNATTENDED_TEXT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_TEXT_FILE, BoxesUnattendedTextFileClass))
#define BOXES_IS_UNATTENDED_TEXT_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_TEXT_FILE))
#define BOXES_IS_UNATTENDED_TEXT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_TEXT_FILE))
#define BOXES_UNATTENDED_TEXT_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_TEXT_FILE, BoxesUnattendedTextFileClass))

typedef struct _BoxesUnattendedTextFile BoxesUnattendedTextFile;
typedef struct _BoxesUnattendedTextFileClass BoxesUnattendedTextFileClass;

#define BOXES_TYPE_ISO_EXTRACTOR (boxes_iso_extractor_get_type ())
#define BOXES_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractor))
#define BOXES_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))
#define BOXES_IS_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_IS_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_ISO_EXTRACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))

typedef struct _BoxesISOExtractor BoxesISOExtractor;
typedef struct _BoxesISOExtractorClass BoxesISOExtractorClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_UNATTENDED_RAW_FILE (boxes_unattended_raw_file_get_type ())
#define BOXES_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile))
#define BOXES_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))
#define BOXES_IS_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_IS_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_UNATTENDED_RAW_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))

typedef struct _BoxesUnattendedRawFile BoxesUnattendedRawFile;
typedef struct _BoxesUnattendedRawFileClass BoxesUnattendedRawFileClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesWinXpInstallerPrepareForInstallationData BoxesWinXpInstallerPrepareForInstallationData;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkVBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_user_data_for_vm_creation_available) (BoxesInstallerMedia* self);
	gboolean (*get_supports_virtio_disk) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedFileIface {
	GTypeInterface parent_iface;
	void (*get_source_file) (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GFile* (*get_source_file_finish) (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
	const gchar* (*get_src_path) (BoxesUnattendedFile* self);
	void (*set_src_path) (BoxesUnattendedFile* self, const gchar* value);
	const gchar* (*get_dest_name) (BoxesUnattendedFile* self);
	void (*set_dest_name) (BoxesUnattendedFile* self, const gchar* value);
	BoxesUnattendedInstaller* (*get_installer) (BoxesUnattendedFile* self);
	void (*set_installer) (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	GDataStreamNewlineType newline_type;
	GFile* disk_file;
	GList* unattended_files;
	GtkTable* setup_table;
	GtkLabel* setup_label;
	GtkHBox* setup_hbox;
	GtkSwitch* express_toggle;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	gchar* timezone;
	gchar* lang;
	gchar* hostname;
	AvatarFormat* avatar_format;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
	gchar* (*fill_unattended_data) (BoxesUnattendedInstaller* self, const gchar* data, GError** error);
	void (*setup_ui) (BoxesUnattendedInstaller* self);
	void (*clean_up) (BoxesUnattendedInstaller* self, GError** error);
	GVirConfigDomainDisk* (*get_unattended_disk_config) (BoxesUnattendedInstaller* self);
};

struct _BoxesWindowsInstaller {
	BoxesUnattendedInstaller parent_instance;
	BoxesWindowsInstallerPrivate * priv;
};

struct _BoxesWindowsInstallerClass {
	BoxesUnattendedInstallerClass parent_class;
};

struct _BoxesWinXPInstaller {
	BoxesWindowsInstaller parent_instance;
	BoxesWinXPInstallerPrivate * priv;
};

struct _BoxesWinXPInstallerClass {
	BoxesWindowsInstallerClass parent_class;
};

struct _BoxesWinXPInstallerPrivate {
	GtkEntry* key_entry;
	gulong key_inserted_id;
	gboolean has_viostor_drivers;
};

struct _BoxesWinXpInstallerPrepareForInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWinXPInstaller* self;
	gchar* vm_name;
	GCancellable* cancellable;
	gboolean have_viostor;
	const gchar* _tmp0_;
	GCancellable* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	BoxesISOExtractor* _tmp9_;
	BoxesISOExtractor* _tmp10_;
	BoxesISOExtractor* extractor;
	BoxesISOExtractor* _tmp11_;
	GCancellable* _tmp12_;
	const gchar* _tmp13_;
	OsinfoMedia* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gboolean _tmp18_;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* driver_path;
	BoxesISOExtractor* _tmp21_;
	const gchar* _tmp22_;
	GCancellable* _tmp23_;
	GFileEnumerator* _tmp24_;
	GFileEnumerator* enumerator;
	GFileEnumerator* _tmp25_;
	GCancellable* _tmp26_;
	GList* _tmp27_;
	GList* infos;
	GList* _tmp28_;
	GList* _tmp29_;
	GList* info_collection;
	GList* info_it;
	GFileInfo* _tmp30_;
	GFileInfo* info;
	const gchar* _tmp31_;
	GFileInfo* _tmp32_;
	const gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* relative_path;
	BoxesISOExtractor* _tmp35_;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* full_path;
	const gchar* _tmp38_;
	GFileInfo* _tmp39_;
	const gchar* _tmp40_;
	BoxesUnattendedRawFile* _tmp41_;
	BoxesUnattendedRawFile* unattended_file;
	const gchar* _tmp42_;
	BoxesUnattendedRawFile* _tmp43_;
	GCancellable* _tmp44_;
	GFileInfo* _tmp45_;
	const gchar* _tmp46_;
	GFileEnumerator* _tmp47_;
	GCancellable* _tmp48_;
	GList* _tmp49_;
	GList* _tmp50_;
	gboolean _tmp51_;
	GError* e;
	GError * _inner_error_;
};


static gpointer boxes_win_xp_installer_parent_class = NULL;
static GRegex* boxes_win_xp_installer_key_regex;
static GRegex* boxes_win_xp_installer_key_regex = NULL;
static GRegex* boxes_win_xp_installer_admin_pass_regex;
static GRegex* boxes_win_xp_installer_admin_pass_regex = NULL;

GType boxes_installer_media_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_file_get_type (void) G_GNUC_CONST;
gpointer avatar_format_ref (gpointer instance);
void avatar_format_unref (gpointer instance);
GParamSpec* param_spec_avatar_format (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_avatar_format (GValue* value, gpointer v_object);
void value_take_avatar_format (GValue* value, gpointer v_object);
gpointer value_get_avatar_format (const GValue* value);
GType avatar_format_get_type (void) G_GNUC_CONST;
GType boxes_windows_installer_get_type (void) G_GNUC_CONST;
GType boxes_win_xp_installer_get_type (void) G_GNUC_CONST;
#define BOXES_WIN_XP_INSTALLER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstallerPrivate))
enum  {
	BOXES_WIN_XP_INSTALLER_DUMMY_PROPERTY,
	BOXES_WIN_XP_INSTALLER_USER_DATA_FOR_VM_CREATION_AVAILABLE,
	BOXES_WIN_XP_INSTALLER_SUPPORTS_VIRTIO_DISK
};
BoxesWinXPInstaller* boxes_win_xp_installer_new_from_media (BoxesInstallerMedia* media, GError** error);
BoxesWinXPInstaller* boxes_win_xp_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, GError** error);
AvatarFormat* avatar_format_new (const gchar* type, const gchar* extension, gboolean alpha, gint width, gint height);
AvatarFormat* avatar_format_construct (GType object_type, const gchar* type, const gchar* extension, gboolean alpha, gint width, gint height);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, const gchar* unattended_src_path, const gchar* unattended_dest_name, AvatarFormat* avatar_format, GError** error);
void boxes_unattended_installer_add_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file);
BoxesUnattendedTextFile* boxes_unattended_text_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
BoxesUnattendedTextFile* boxes_unattended_text_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
GType boxes_unattended_text_file_get_type (void) G_GNUC_CONST;
void boxes_unattended_installer_set_extra_iso (BoxesUnattendedInstaller* self, const gchar* value);
static void boxes_win_xp_installer_real_prepare_for_installation_data_free (gpointer _data);
static void boxes_win_xp_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_win_xp_installer_real_prepare_for_installation_co (BoxesWinXpInstallerPrepareForInstallationData* _data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
static void boxes_win_xp_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gchar* boxes_unattended_installer_get_extra_iso (BoxesUnattendedInstaller* self);
BoxesISOExtractor* boxes_iso_extractor_new (const gchar* iso_path);
BoxesISOExtractor* boxes_iso_extractor_construct (GType object_type, const gchar* iso_path);
GType boxes_iso_extractor_get_type (void) G_GNUC_CONST;
void boxes_iso_extractor_mount_media (BoxesISOExtractor* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_iso_extractor_mount_media_finish (BoxesISOExtractor* self, GAsyncResult* _res_, GError** error);
void boxes_iso_extractor_enumerate_children (BoxesISOExtractor* self, const gchar* rel_path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFileEnumerator* boxes_iso_extractor_enumerate_children_finish (BoxesISOExtractor* self, GAsyncResult* _res_, GError** error);
gchar* boxes_iso_extractor_get_absolute_path (BoxesISOExtractor* self, const gchar* relative_path, GError** error);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesUnattendedRawFile* boxes_unattended_raw_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
BoxesUnattendedRawFile* boxes_unattended_raw_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
GType boxes_unattended_raw_file_get_type (void) G_GNUC_CONST;
void boxes_unattended_file_copy (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_unattended_file_copy_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
static void boxes_win_xp_installer_real_setup_ui (BoxesUnattendedInstaller* base);
void boxes_unattended_installer_setup_ui (BoxesUnattendedInstaller* self);
GtkEntry* boxes_unattended_installer_create_input_entry (BoxesUnattendedInstaller* self, const gchar* text, gboolean mandatory, gboolean visibility);
static void boxes_win_xp_installer_on_key_text_inserted (BoxesWinXPInstaller* self, const gchar* text, gint text_length, gint* position);
static void _boxes_win_xp_installer_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
static gchar* boxes_win_xp_installer_real_fill_unattended_data (BoxesUnattendedInstaller* base, const gchar* data, GError** error);
gchar* boxes_unattended_installer_fill_unattended_data (BoxesUnattendedInstaller* self, const gchar* data, GError** error);
gchar* boxes_unattended_installer_get_password (BoxesUnattendedInstaller* self);
static gboolean _vala_uint_array_contains (guint* stack, int stack_length, guint needle);
BoxesWinXPInstaller* boxes_win_xp_installer_new (void);
BoxesWinXPInstaller* boxes_win_xp_installer_construct (GType object_type);
BoxesWindowsInstaller* boxes_windows_installer_construct (GType object_type);
gboolean boxes_installer_media_get_user_data_for_vm_creation_available (BoxesInstallerMedia* self);
static void boxes_win_xp_installer_finalize (GObject* obj);
gboolean boxes_installer_media_get_supports_virtio_disk (BoxesInstallerMedia* self);
static void _vala_boxes_win_xp_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);

static const guint BOXES_WIN_XP_INSTALLER_allowed_dash_positions[4] = {(guint) 5, (guint) 11, (guint) 17, (guint) 23};

BoxesWinXPInstaller* boxes_win_xp_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, GError** error) {
	BoxesWinXPInstaller * self = NULL;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_;
	gchar* unattended_source;
	AvatarFormat* _tmp8_;
	AvatarFormat* avatar_format;
	BoxesInstallerMedia* _tmp9_;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	OsinfoOs* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* name;
	const gchar* _tmp16_;
	gchar* _tmp17_ = NULL;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	BoxesUnattendedTextFile* _tmp20_;
	BoxesUnattendedTextFile* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	OsinfoOs* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_ = NULL;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	BoxesUnattendedTextFile* _tmp31_;
	BoxesUnattendedTextFile* _tmp32_;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (media != NULL, NULL);
	_tmp0_ = media;
	_tmp1_ = _tmp0_->os;
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat (_tmp3_, ".sif", NULL);
	_tmp5_ = _tmp4_;
	_tmp6_ = boxes_get_unattended (_tmp5_);
	_tmp7_ = _tmp6_;
	_g_free0 (_tmp5_);
	unattended_source = _tmp7_;
	_tmp8_ = avatar_format_new ("bmp", ".bmp", FALSE, 48, 48);
	avatar_format = _tmp8_;
	_tmp9_ = media;
	_tmp10_ = unattended_source;
	self = (BoxesWinXPInstaller*) boxes_unattended_installer_construct_from_media (object_type, _tmp9_, _tmp10_, "Winnt.sif", avatar_format, &_inner_error_);
	if (_inner_error_ != NULL) {
		g_propagate_error (error, _inner_error_);
		_avatar_format_unref0 (avatar_format);
		_g_free0 (unattended_source);
		_g_object_unref0 (self);
		return NULL;
	}
	_tmp11_ = media;
	_tmp12_ = _tmp11_->os;
	_tmp13_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp12_);
	_tmp14_ = _tmp13_;
	_tmp15_ = g_strconcat (_tmp14_, ".cmd", NULL);
	name = _tmp15_;
	_tmp16_ = name;
	_tmp17_ = boxes_get_unattended (_tmp16_);
	_g_free0 (unattended_source);
	unattended_source = _tmp17_;
	_tmp18_ = unattended_source;
	_tmp19_ = name;
	_tmp20_ = boxes_unattended_text_file_new ((BoxesUnattendedInstaller*) self, _tmp18_, _tmp19_);
	_tmp21_ = _tmp20_;
	boxes_unattended_installer_add_unattended_file ((BoxesUnattendedInstaller*) self, (BoxesUnattendedFile*) _tmp21_);
	_g_object_unref0 (_tmp21_);
	_tmp22_ = media;
	_tmp23_ = _tmp22_->os;
	_tmp24_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp23_);
	_tmp25_ = _tmp24_;
	_tmp26_ = g_strconcat (_tmp25_, ".reg", NULL);
	_g_free0 (name);
	name = _tmp26_;
	_tmp27_ = name;
	_tmp28_ = boxes_get_unattended (_tmp27_);
	_g_free0 (unattended_source);
	unattended_source = _tmp28_;
	_tmp29_ = unattended_source;
	_tmp30_ = name;
	_tmp31_ = boxes_unattended_text_file_new ((BoxesUnattendedInstaller*) self, _tmp29_, _tmp30_);
	_tmp32_ = _tmp31_;
	boxes_unattended_installer_add_unattended_file ((BoxesUnattendedInstaller*) self, (BoxesUnattendedFile*) _tmp32_);
	_g_object_unref0 (_tmp32_);
	((BoxesUnattendedInstaller*) self)->newline_type = G_DATA_STREAM_NEWLINE_TYPE_CR_LF;
	boxes_unattended_installer_set_extra_iso ((BoxesUnattendedInstaller*) self, "win-tools.iso");
	_g_free0 (name);
	_avatar_format_unref0 (avatar_format);
	_g_free0 (unattended_source);
	return self;
}


BoxesWinXPInstaller* boxes_win_xp_installer_new_from_media (BoxesInstallerMedia* media, GError** error) {
	return boxes_win_xp_installer_construct_from_media (BOXES_TYPE_WIN_XP_INSTALLER, media, error);
}


static void boxes_win_xp_installer_real_prepare_for_installation_data_free (gpointer _data) {
	BoxesWinXpInstallerPrepareForInstallationData* _data_;
	_data_ = _data;
	_g_free0 (_data_->vm_name);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (BoxesWinXpInstallerPrepareForInstallationData, _data_);
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static void boxes_win_xp_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWinXPInstaller * self;
	BoxesWinXpInstallerPrepareForInstallationData* _data_;
	BoxesWinXPInstaller* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
	self = (BoxesWinXPInstaller*) base;
	_data_ = g_slice_new0 (BoxesWinXpInstallerPrepareForInstallationData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_win_xp_installer_real_prepare_for_installation);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_win_xp_installer_real_prepare_for_installation_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = vm_name;
	_tmp2_ = g_strdup (_tmp1_);
	_data_->vm_name = _tmp2_;
	_tmp3_ = cancellable;
	_tmp4_ = _g_object_ref0 (_tmp3_);
	_data_->cancellable = _tmp4_;
	boxes_win_xp_installer_real_prepare_for_installation_co (_data_);
}


static void boxes_win_xp_installer_real_prepare_for_installation_finish (BoxesInstallerMedia* base, GAsyncResult* _res_, GError** error) {
	BoxesWinXpInstallerPrepareForInstallationData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


static void boxes_win_xp_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWinXpInstallerPrepareForInstallationData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	boxes_win_xp_installer_real_prepare_for_installation_co (_data_);
}


static void _g_object_unref0_ (gpointer var) {
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}


static void _g_list_free__g_object_unref0_ (GList* self) {
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
	g_list_free (self);
}


static gboolean boxes_win_xp_installer_real_prepare_for_installation_co (BoxesWinXpInstallerPrepareForInstallationData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		case 3:
		goto _state_3;
		case 4:
		goto _state_4;
		case 5:
		goto _state_5;
		case 6:
		goto _state_6;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->have_viostor = FALSE;
	_data_->self->priv->has_viostor_drivers = FALSE;
	_data_->_tmp0_ = _data_->vm_name;
	_data_->_tmp1_ = _data_->cancellable;
	_data_->_state_ = 1;
	BOXES_INSTALLER_MEDIA_CLASS (boxes_win_xp_installer_parent_class)->prepare_for_installation ((BoxesInstallerMedia*) G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller), _data_->_tmp0_, _data_->_tmp1_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
	return FALSE;
	_state_1:
	BOXES_INSTALLER_MEDIA_CLASS (boxes_win_xp_installer_parent_class)->prepare_for_installation_finish ((BoxesInstallerMedia*) G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller), _data_->_res_, &_data_->_inner_error_);
	if (_data_->_inner_error_ != NULL) {
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
		g_error_free (_data_->_inner_error_);
		if (_data_->_state_ == 0) {
			g_simple_async_result_complete_in_idle (_data_->_async_result);
		} else {
			g_simple_async_result_complete (_data_->_async_result);
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp2_ = boxes_unattended_installer_get_extra_iso ((BoxesUnattendedInstaller*) _data_->self);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = _data_->_tmp3_;
	_data_->_tmp5_ = _data_->_tmp4_ == NULL;
	_g_free0 (_data_->_tmp4_);
	if (_data_->_tmp5_) {
		if (_data_->_state_ == 0) {
			g_simple_async_result_complete_in_idle (_data_->_async_result);
		} else {
			g_simple_async_result_complete (_data_->_async_result);
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	{
		_data_->_tmp6_ = boxes_unattended_installer_get_extra_iso ((BoxesUnattendedInstaller*) _data_->self);
		_data_->_tmp7_ = _data_->_tmp6_;
		_data_->_tmp8_ = _data_->_tmp7_;
		_data_->_tmp9_ = boxes_iso_extractor_new (_data_->_tmp8_);
		_data_->_tmp10_ = _data_->_tmp9_;
		_g_free0 (_data_->_tmp8_);
		_data_->extractor = _data_->_tmp10_;
		_data_->_tmp11_ = _data_->extractor;
		_data_->_tmp12_ = _data_->cancellable;
		_data_->_state_ = 2;
		boxes_iso_extractor_mount_media (_data_->_tmp11_, _data_->_tmp12_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
		return FALSE;
		_state_2:
		boxes_iso_extractor_mount_media_finish (_data_->_tmp11_, _data_->_res_, &_data_->_inner_error_);
		if (_data_->_inner_error_ != NULL) {
			_g_object_unref0 (_data_->extractor);
			goto __catch75_g_error;
		}
		_data_->_tmp14_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
		_data_->_tmp15_ = NULL;
		g_object_get (_data_->_tmp14_, "architecture", &_data_->_tmp15_, NULL);
		_data_->_tmp16_ = _data_->_tmp15_;
		_data_->_tmp17_ = _data_->_tmp16_;
		_data_->_tmp18_ = g_strcmp0 (_data_->_tmp17_, "x86_64") == 0;
		_g_free0 (_data_->_tmp17_);
		if (_data_->_tmp18_) {
			_data_->_tmp13_ = "preinst/winxp/amd64";
		} else {
			_data_->_tmp13_ = "preinst/winxp/x86";
		}
		_data_->_tmp19_ = _data_->_tmp13_;
		_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
		_data_->driver_path = _data_->_tmp20_;
		_data_->_tmp21_ = _data_->extractor;
		_data_->_tmp22_ = _data_->driver_path;
		_data_->_tmp23_ = _data_->cancellable;
		_data_->_state_ = 3;
		boxes_iso_extractor_enumerate_children (_data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
		return FALSE;
		_state_3:
		_data_->_tmp24_ = NULL;
		_data_->_tmp24_ = boxes_iso_extractor_enumerate_children_finish (_data_->_tmp21_, _data_->_res_, &_data_->_inner_error_);
		_data_->enumerator = _data_->_tmp24_;
		if (_data_->_inner_error_ != NULL) {
			_g_free0 (_data_->driver_path);
			_g_object_unref0 (_data_->extractor);
			goto __catch75_g_error;
		}
		_data_->_tmp25_ = _data_->enumerator;
		_data_->_tmp26_ = _data_->cancellable;
		_data_->_state_ = 4;
		g_file_enumerator_next_files_async (_data_->_tmp25_, 4, G_PRIORITY_DEFAULT, _data_->_tmp26_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
		return FALSE;
		_state_4:
		_data_->_tmp27_ = NULL;
		_data_->_tmp27_ = g_file_enumerator_next_files_finish (_data_->_tmp25_, _data_->_res_, &_data_->_inner_error_);
		_data_->infos = _data_->_tmp27_;
		if (_data_->_inner_error_ != NULL) {
			_g_object_unref0 (_data_->enumerator);
			_g_free0 (_data_->driver_path);
			_g_object_unref0 (_data_->extractor);
			goto __catch75_g_error;
		}
		while (TRUE) {
			_data_->_tmp28_ = _data_->infos;
			if (!(_data_->_tmp28_ != NULL)) {
				break;
			}
			_data_->_tmp29_ = _data_->infos;
			{
				_data_->info_collection = _data_->_tmp29_;
				for (_data_->info_it = _data_->info_collection; _data_->info_it != NULL; _data_->info_it = _data_->info_it->next) {
					_data_->_tmp30_ = _g_object_ref0 ((GFileInfo*) _data_->info_it->data);
					_data_->info = _data_->_tmp30_;
					{
						_data_->_tmp31_ = _data_->driver_path;
						_data_->_tmp32_ = _data_->info;
						_data_->_tmp33_ = NULL;
						_data_->_tmp33_ = g_file_info_get_name (_data_->_tmp32_);
						_data_->_tmp34_ = NULL;
						_data_->_tmp34_ = g_build_filename (_data_->_tmp31_, _data_->_tmp33_, NULL);
						_data_->relative_path = _data_->_tmp34_;
						_data_->_tmp35_ = _data_->extractor;
						_data_->_tmp36_ = _data_->relative_path;
						_data_->_tmp37_ = NULL;
						_data_->_tmp37_ = boxes_iso_extractor_get_absolute_path (_data_->_tmp35_, _data_->_tmp36_, &_data_->_inner_error_);
						_data_->full_path = _data_->_tmp37_;
						if (_data_->_inner_error_ != NULL) {
							_g_free0 (_data_->relative_path);
							_g_object_unref0 (_data_->info);
							__g_list_free__g_object_unref0_0 (_data_->infos);
							_g_object_unref0 (_data_->enumerator);
							_g_free0 (_data_->driver_path);
							_g_object_unref0 (_data_->extractor);
							goto __catch75_g_error;
						}
						_data_->_tmp38_ = _data_->full_path;
						_data_->_tmp39_ = _data_->info;
						_data_->_tmp40_ = NULL;
						_data_->_tmp40_ = g_file_info_get_name (_data_->_tmp39_);
						_data_->_tmp41_ = boxes_unattended_raw_file_new ((BoxesUnattendedInstaller*) _data_->self, _data_->_tmp38_, _data_->_tmp40_);
						_data_->unattended_file = _data_->_tmp41_;
						_data_->_tmp42_ = _data_->relative_path;
						g_debug ("winxp-installer.vala:79: Copying %s from extra ISO to unattended flopp" \
"y", _data_->_tmp42_);
						_data_->_tmp43_ = _data_->unattended_file;
						_data_->_tmp44_ = _data_->cancellable;
						_data_->_state_ = 5;
						boxes_unattended_file_copy ((BoxesUnattendedFile*) _data_->_tmp43_, _data_->_tmp44_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
						return FALSE;
						_state_5:
						boxes_unattended_file_copy_finish ((BoxesUnattendedFile*) _data_->_tmp43_, _data_->_res_, &_data_->_inner_error_);
						if (_data_->_inner_error_ != NULL) {
							_g_object_unref0 (_data_->unattended_file);
							_g_free0 (_data_->full_path);
							_g_free0 (_data_->relative_path);
							_g_object_unref0 (_data_->info);
							__g_list_free__g_object_unref0_0 (_data_->infos);
							_g_object_unref0 (_data_->enumerator);
							_g_free0 (_data_->driver_path);
							_g_object_unref0 (_data_->extractor);
							goto __catch75_g_error;
						}
						_data_->_tmp45_ = _data_->info;
						_data_->_tmp46_ = NULL;
						_data_->_tmp46_ = g_file_info_get_name (_data_->_tmp45_);
						if (g_strcmp0 (_data_->_tmp46_, "viostor.sys") == 0) {
							_data_->have_viostor = TRUE;
						}
						_g_object_unref0 (_data_->unattended_file);
						_g_free0 (_data_->full_path);
						_g_free0 (_data_->relative_path);
						_g_object_unref0 (_data_->info);
					}
				}
			}
			_data_->_tmp47_ = _data_->enumerator;
			_data_->_tmp48_ = _data_->cancellable;
			_data_->_state_ = 6;
			g_file_enumerator_next_files_async (_data_->_tmp47_, 4, G_PRIORITY_DEFAULT, _data_->_tmp48_, boxes_win_xp_installer_prepare_for_installation_ready, _data_);
			return FALSE;
			_state_6:
			_data_->_tmp49_ = NULL;
			_data_->_tmp49_ = g_file_enumerator_next_files_finish (_data_->_tmp47_, _data_->_res_, &_data_->_inner_error_);
			_data_->_tmp50_ = _data_->_tmp49_;
			if (_data_->_inner_error_ != NULL) {
				__g_list_free__g_object_unref0_0 (_data_->infos);
				_g_object_unref0 (_data_->enumerator);
				_g_free0 (_data_->driver_path);
				_g_object_unref0 (_data_->extractor);
				goto __catch75_g_error;
			}
			__g_list_free__g_object_unref0_0 (_data_->infos);
			_data_->infos = _data_->_tmp50_;
		}
		_data_->_tmp51_ = _data_->have_viostor;
		_data_->self->priv->has_viostor_drivers = _data_->_tmp51_;
		__g_list_free__g_object_unref0_0 (_data_->infos);
		_g_object_unref0 (_data_->enumerator);
		_g_free0 (_data_->driver_path);
		_g_object_unref0 (_data_->extractor);
	}
	goto __finally75;
	__catch75_g_error:
	{
		_data_->e = _data_->_inner_error_;
		_data_->_inner_error_ = NULL;
		_data_->self->priv->has_viostor_drivers = FALSE;
		_g_error_free0 (_data_->e);
	}
	__finally75:
	if (_data_->_inner_error_ != NULL) {
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
		g_error_free (_data_->_inner_error_);
		if (_data_->_state_ == 0) {
			g_simple_async_result_complete_in_idle (_data_->_async_result);
		} else {
			g_simple_async_result_complete (_data_->_async_result);
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void _boxes_win_xp_installer_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
	boxes_win_xp_installer_on_key_text_inserted (self, new_text, new_text_length, position);
}


static void boxes_win_xp_installer_real_setup_ui (BoxesUnattendedInstaller* base) {
	BoxesWinXPInstaller * self;
	GtkTable* _tmp0_;
	GtkTable* _tmp1_;
	guint _tmp2_ = 0U;
	guint _tmp3_;
	GtkTable* _tmp4_;
	guint _tmp5_ = 0U;
	guint _tmp6_;
	GtkHBox* _tmp7_;
	GtkHBox* hbox;
	const gchar* _tmp8_ = NULL;
	GtkLabel* _tmp9_;
	GtkLabel* label;
	GtkEntry* _tmp10_ = NULL;
	GtkEntry* _tmp11_;
	GtkEntry* _tmp12_;
	GtkEntry* _tmp13_;
	GtkStyleContext* _tmp14_ = NULL;
	GtkEntry* _tmp15_;
	GtkTable* _tmp16_;
	GtkTable* _tmp17_;
	guint _tmp18_ = 0U;
	guint _tmp19_;
	GtkTable* _tmp20_;
	guint _tmp21_ = 0U;
	guint _tmp22_;
	GtkTable* _tmp23_;
	guint _tmp24_ = 0U;
	guint _tmp25_;
	GtkSwitch* _tmp26_;
	GtkEntry* _tmp27_;
	gulong _tmp28_ = 0UL;
	self = (BoxesWinXPInstaller*) base;
	BOXES_UNATTENDED_INSTALLER_CLASS (boxes_win_xp_installer_parent_class)->setup_ui ((BoxesUnattendedInstaller*) G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller));
	_tmp0_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	_tmp1_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	g_object_get (_tmp1_, "n-rows", &_tmp2_, NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	g_object_get (_tmp4_, "n-columns", &_tmp5_, NULL);
	_tmp6_ = _tmp5_;
	gtk_table_resize (_tmp0_, _tmp3_ + 1, _tmp6_);
	_tmp7_ = (GtkHBox*) gtk_hbox_new (FALSE, 10);
	g_object_ref_sink (_tmp7_);
	hbox = _tmp7_;
	gtk_widget_set_margin_top ((GtkWidget*) hbox, 12);
	_tmp8_ = _ ("Product Key");
	_tmp9_ = (GtkLabel*) gtk_label_new (_tmp8_);
	g_object_ref_sink (_tmp9_);
	label = _tmp9_;
	gtk_widget_set_halign ((GtkWidget*) label, GTK_ALIGN_START);
	gtk_box_pack_start ((GtkBox*) hbox, (GtkWidget*) label, TRUE, TRUE, (guint) 0);
	_tmp10_ = boxes_unattended_installer_create_input_entry ((BoxesUnattendedInstaller*) self, "", TRUE, TRUE);
	_g_object_unref0 (self->priv->key_entry);
	self->priv->key_entry = _tmp10_;
	_tmp11_ = self->priv->key_entry;
	gtk_entry_set_width_chars (_tmp11_, 29);
	_tmp12_ = self->priv->key_entry;
	gtk_entry_set_max_length (_tmp12_, 29);
	_tmp13_ = self->priv->key_entry;
	_tmp14_ = gtk_widget_get_style_context ((GtkWidget*) _tmp13_);
	gtk_style_context_add_class (_tmp14_, "boxes-product-key-entry");
	_tmp15_ = self->priv->key_entry;
	gtk_box_pack_start ((GtkBox*) hbox, (GtkWidget*) _tmp15_, TRUE, TRUE, (guint) 0);
	_tmp16_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	_tmp17_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	g_object_get (_tmp17_, "n-columns", &_tmp18_, NULL);
	_tmp19_ = _tmp18_;
	_tmp20_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	g_object_get (_tmp20_, "n-rows", &_tmp21_, NULL);
	_tmp22_ = _tmp21_;
	_tmp23_ = ((BoxesUnattendedInstaller*) self)->setup_table;
	g_object_get (_tmp23_, "n-rows", &_tmp24_, NULL);
	_tmp25_ = _tmp24_;
	gtk_table_attach_defaults (_tmp16_, (GtkWidget*) hbox, (guint) 0, _tmp19_, _tmp22_ - 1, _tmp25_);
	_tmp26_ = ((BoxesUnattendedInstaller*) self)->express_toggle;
	g_object_bind_property_with_closures ((GObject*) _tmp26_, "active", (GObject*) hbox, "sensitive", 0, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
	_tmp27_ = self->priv->key_entry;
	_tmp28_ = g_signal_connect_object ((GtkEditable*) _tmp27_, "insert-text", (GCallback) _boxes_win_xp_installer_on_key_text_inserted_gtk_editable_insert_text, self, 0);
	self->priv->key_inserted_id = _tmp28_;
	_g_object_unref0 (label);
	_g_object_unref0 (hbox);
}


static gchar* boxes_win_xp_installer_real_fill_unattended_data (BoxesUnattendedInstaller* base, const gchar* data, GError** error) {
	BoxesWinXPInstaller * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* str;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* admin_pass;
	GRegex* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_;
	GRegex* _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	GtkEntry* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_;
	GError * _inner_error_ = NULL;
	self = (BoxesWinXPInstaller*) base;
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = data;
	_tmp1_ = BOXES_UNATTENDED_INSTALLER_CLASS (boxes_win_xp_installer_parent_class)->fill_unattended_data ((BoxesUnattendedInstaller*) G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller), _tmp0_, &_inner_error_);
	str = _tmp1_;
	if (_inner_error_ != NULL) {
		if (_inner_error_->domain == G_REGEX_ERROR) {
			g_propagate_error (error, _inner_error_);
			return NULL;
		} else {
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
	}
	_tmp3_ = boxes_unattended_installer_get_password ((BoxesUnattendedInstaller*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = g_strcmp0 (_tmp5_, "") != 0;
	_g_free0 (_tmp5_);
	if (_tmp6_) {
		gchar* _tmp7_;
		gchar* _tmp8_;
		_tmp7_ = boxes_unattended_installer_get_password ((BoxesUnattendedInstaller*) self);
		_tmp8_ = _tmp7_;
		_g_free0 (_tmp2_);
		_tmp2_ = _tmp8_;
	} else {
		gchar* _tmp9_;
		_tmp9_ = g_strdup ("*");
		_g_free0 (_tmp2_);
		_tmp2_ = _tmp9_;
	}
	_tmp10_ = _tmp2_;
	_tmp11_ = g_strdup (_tmp10_);
	admin_pass = _tmp11_;
	_tmp12_ = boxes_win_xp_installer_admin_pass_regex;
	_tmp13_ = str;
	_tmp14_ = str;
	_tmp15_ = strlen (_tmp14_);
	_tmp16_ = _tmp15_;
	_tmp17_ = admin_pass;
	_tmp18_ = g_regex_replace (_tmp12_, _tmp13_, (gssize) _tmp16_, 0, _tmp17_, 0, &_inner_error_);
	_tmp19_ = _tmp18_;
	if (_inner_error_ != NULL) {
		if (_inner_error_->domain == G_REGEX_ERROR) {
			g_propagate_error (error, _inner_error_);
			_g_free0 (admin_pass);
			_g_free0 (_tmp2_);
			_g_free0 (str);
			return NULL;
		} else {
			_g_free0 (admin_pass);
			_g_free0 (_tmp2_);
			_g_free0 (str);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
	}
	_g_free0 (str);
	str = _tmp19_;
	_tmp20_ = boxes_win_xp_installer_key_regex;
	_tmp21_ = str;
	_tmp22_ = str;
	_tmp23_ = strlen (_tmp22_);
	_tmp24_ = _tmp23_;
	_tmp25_ = self->priv->key_entry;
	_tmp26_ = gtk_entry_get_text (_tmp25_);
	_tmp27_ = _tmp26_;
	_tmp28_ = g_regex_replace (_tmp20_, _tmp21_, (gssize) _tmp24_, 0, _tmp27_, 0, &_inner_error_);
	_tmp29_ = _tmp28_;
	if (_inner_error_ != NULL) {
		if (_inner_error_->domain == G_REGEX_ERROR) {
			g_propagate_error (error, _inner_error_);
			_g_free0 (admin_pass);
			_g_free0 (_tmp2_);
			_g_free0 (str);
			return NULL;
		} else {
			_g_free0 (admin_pass);
			_g_free0 (_tmp2_);
			_g_free0 (str);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
	}
	result = _tmp29_;
	_g_free0 (admin_pass);
	_g_free0 (_tmp2_);
	_g_free0 (str);
	return result;
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	res = (guint8*) self;
	res_length1 = -1;
	_res_size_ = res_length1;
	_tmp0_ = strlen (self);
	_tmp1_ = _tmp0_;
	res_length1 = (gint) _tmp1_;
	_tmp2_ = res_length1;
	_tmp3_ = res;
	_tmp3__length1 = res_length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}


static gboolean _vala_uint_array_contains (guint* stack, int stack_length, guint needle) {
	int i;
	for (i = 0; i < stack_length; i++) {
		if (needle == stack[i]) {
			return TRUE;
		}
	}
	return FALSE;
}


static void boxes_win_xp_installer_on_key_text_inserted (BoxesWinXPInstaller* self, const gchar* text, gint text_length, gint* position) {
	gchar* _tmp0_;
	gchar* _result_;
	guint i;
	const gchar* _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
	guint8* _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp20_;
	GtkEntry* _tmp32_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (text != NULL);
	_tmp0_ = g_strdup ("");
	_result_ = _tmp0_;
	i = (guint) 0;
	_tmp1_ = text;
	_tmp2_ = string_get_data (_tmp1_, &_tmp2__length1);
	_tmp3_ = _tmp2_;
	_tmp3__length1 = _tmp2__length1;
	{
		gchar* character_collection = NULL;
		gint character_collection_length1 = 0;
		gint _character_collection_size_ = 0;
		gint character_it = 0;
		character_collection = (gchar*) _tmp3_;
		character_collection_length1 = (_tmp3__length1 * sizeof (guint8)) / sizeof (gchar);
		for (character_it = 0; character_it < ((_tmp3__length1 * sizeof (guint8)) / sizeof (gchar)); character_it = character_it + 1) {
			gchar character = '\0';
			character = character_collection[character_it];
			{
				guint _tmp4_;
				gint _tmp5_;
				guint char_position;
				gchar _tmp6_;
				const gchar* _tmp14_;
				gchar _tmp15_;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_;
				gchar* _tmp18_;
				guint _tmp19_;
				_tmp4_ = i;
				_tmp5_ = *position;
				char_position = _tmp4_ + _tmp5_;
				_tmp6_ = character;
				if (_tmp6_ != '-') {
					gchar _tmp7_;
					gboolean _tmp8_ = FALSE;
					guint _tmp9_;
					_tmp7_ = character;
					_tmp8_ = g_ascii_isalnum (_tmp7_);
					if (!_tmp8_) {
						continue;
					}
					_tmp9_ = char_position;
					if (_vala_uint_array_contains (BOXES_WIN_XP_INSTALLER_allowed_dash_positions, G_N_ELEMENTS (BOXES_WIN_XP_INSTALLER_allowed_dash_positions), _tmp9_)) {
						const gchar* _tmp10_;
						gchar* _tmp11_;
						guint _tmp12_;
						_tmp10_ = _result_;
						_tmp11_ = g_strconcat (_tmp10_, "-", NULL);
						_g_free0 (_result_);
						_result_ = _tmp11_;
						_tmp12_ = i;
						i = _tmp12_ + 1;
					}
				} else {
					guint _tmp13_;
					_tmp13_ = char_position;
					if (!_vala_uint_array_contains (BOXES_WIN_XP_INSTALLER_allowed_dash_positions, G_N_ELEMENTS (BOXES_WIN_XP_INSTALLER_allowed_dash_positions), _tmp13_)) {
						continue;
					}
				}
				_tmp14_ = _result_;
				_tmp15_ = character;
				_tmp16_ = g_strdup_printf ("%c", _tmp15_);
				_tmp17_ = _tmp16_;
				_tmp18_ = g_strconcat (_tmp14_, _tmp17_, NULL);
				_g_free0 (_result_);
				_result_ = _tmp18_;
				_g_free0 (_tmp17_);
				_tmp19_ = i;
				i = _tmp19_ + 1;
			}
		}
	}
	_tmp20_ = _result_;
	if (g_strcmp0 (_tmp20_, "") != 0) {
		GtkEntry* _tmp21_;
		gulong _tmp22_;
		GtkEntry* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_;
		const gchar* _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		GtkEntry* _tmp30_;
		gulong _tmp31_;
		_tmp21_ = self->priv->key_entry;
		_tmp22_ = self->priv->key_inserted_id;
		g_signal_handler_block (_tmp21_, _tmp22_);
		_tmp23_ = self->priv->key_entry;
		_tmp24_ = _result_;
		_tmp25_ = g_utf8_strup (_tmp24_, (gssize) (-1));
		_tmp26_ = _tmp25_;
		_tmp27_ = _result_;
		_tmp28_ = strlen (_tmp27_);
		_tmp29_ = _tmp28_;
		gtk_editable_insert_text ((GtkEditable*) _tmp23_, _tmp26_, _tmp29_, position);
		_g_free0 (_tmp26_);
		_tmp30_ = self->priv->key_entry;
		_tmp31_ = self->priv->key_inserted_id;
		g_signal_handler_unblock (_tmp30_, _tmp31_);
	}
	_tmp32_ = self->priv->key_entry;
	g_signal_stop_emission_by_name (_tmp32_, "insert-text");
	_g_free0 (_result_);
}


BoxesWinXPInstaller* boxes_win_xp_installer_construct (GType object_type) {
	BoxesWinXPInstaller * self = NULL;
	self = (BoxesWinXPInstaller*) boxes_windows_installer_construct (object_type);
	return self;
}


BoxesWinXPInstaller* boxes_win_xp_installer_new (void) {
	return boxes_win_xp_installer_construct (BOXES_TYPE_WIN_XP_INSTALLER);
}


static gboolean boxes_win_xp_installer_real_get_user_data_for_vm_creation_available (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesWinXPInstaller* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp5_;
	self = (BoxesWinXPInstaller*) base;
	_tmp1_ = BOXES_INSTALLER_MEDIA_CLASS (boxes_win_xp_installer_parent_class)->get_user_data_for_vm_creation_available ((BoxesInstallerMedia*) G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_WINDOWS_INSTALLER, BoxesWindowsInstaller));
	if (_tmp1_) {
		GtkEntry* _tmp2_;
		guint _tmp3_;
		guint _tmp4_;
		_tmp2_ = self->priv->key_entry;
		_tmp3_ = gtk_entry_get_text_length (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ == ((guint) 29);
	} else {
		_tmp0_ = FALSE;
	}
	_tmp5_ = _tmp0_;
	result = _tmp5_;
	return result;
}


static gboolean boxes_win_xp_installer_real_get_supports_virtio_disk (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesWinXPInstaller* self;
	gboolean _tmp0_;
	self = (BoxesWinXPInstaller*) base;
	_tmp0_ = self->priv->has_viostor_drivers;
	result = _tmp0_;
	return result;
}


static void boxes_win_xp_installer_class_init (BoxesWinXPInstallerClass * klass) {
	GError * _inner_error_ = NULL;
	boxes_win_xp_installer_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (BoxesWinXPInstallerPrivate));
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_for_installation = boxes_win_xp_installer_real_prepare_for_installation;
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_for_installation_finish = boxes_win_xp_installer_real_prepare_for_installation_finish;
	BOXES_UNATTENDED_INSTALLER_CLASS (klass)->setup_ui = boxes_win_xp_installer_real_setup_ui;
	BOXES_UNATTENDED_INSTALLER_CLASS (klass)->fill_unattended_data = boxes_win_xp_installer_real_fill_unattended_data;
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_user_data_for_vm_creation_available = boxes_win_xp_installer_real_get_user_data_for_vm_creation_available;
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_supports_virtio_disk = boxes_win_xp_installer_real_get_supports_virtio_disk;
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_win_xp_installer_get_property;
	G_OBJECT_CLASS (klass)->finalize = boxes_win_xp_installer_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIN_XP_INSTALLER_USER_DATA_FOR_VM_CREATION_AVAILABLE, g_param_spec_boolean ("user-data-for-vm-creation-available", "user-data-for-vm-creation-available", "user-data-for-vm-creation-available", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIN_XP_INSTALLER_SUPPORTS_VIRTIO_DISK, g_param_spec_boolean ("supports-virtio-disk", "supports-virtio-disk", "supports-virtio-disk", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	{
		GRegex* _tmp0_;
		GRegex* _tmp1_;
		GRegex* _tmp2_;
		GRegex* _tmp3_;
		_tmp0_ = g_regex_new ("BOXES_PRODUCT_KEY", 0, 0, &_inner_error_);
		_tmp1_ = _tmp0_;
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch76_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
		}
		_g_regex_unref0 (boxes_win_xp_installer_key_regex);
		boxes_win_xp_installer_key_regex = _tmp1_;
		_tmp2_ = g_regex_new ("BOXES_XP_ADMIN_PASSWORD", 0, 0, &_inner_error_);
		_tmp3_ = _tmp2_;
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch76_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
		}
		_g_regex_unref0 (boxes_win_xp_installer_admin_pass_regex);
		boxes_win_xp_installer_admin_pass_regex = _tmp3_;
	}
	goto __finally76;
	__catch76_g_regex_error:
	{
		GError* _error_ = NULL;
		_error_ = _inner_error_;
		_inner_error_ = NULL;
		g_assert_not_reached ();
		_g_error_free0 (_error_);
	}
	__finally76:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
	}
}


static void boxes_win_xp_installer_instance_init (BoxesWinXPInstaller * self) {
	self->priv = BOXES_WIN_XP_INSTALLER_GET_PRIVATE (self);
}


static void boxes_win_xp_installer_finalize (GObject* obj) {
	BoxesWinXPInstaller * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstaller);
	_g_object_unref0 (self->priv->key_entry);
	G_OBJECT_CLASS (boxes_win_xp_installer_parent_class)->finalize (obj);
}


GType boxes_win_xp_installer_get_type (void) {
	static volatile gsize boxes_win_xp_installer_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_win_xp_installer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWinXPInstallerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_win_xp_installer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWinXPInstaller), 0, (GInstanceInitFunc) boxes_win_xp_installer_instance_init, NULL };
		GType boxes_win_xp_installer_type_id;
		boxes_win_xp_installer_type_id = g_type_register_static (BOXES_TYPE_WINDOWS_INSTALLER, "BoxesWinXPInstaller", &g_define_type_info, 0);
		g_once_init_leave (&boxes_win_xp_installer_type_id__volatile, boxes_win_xp_installer_type_id);
	}
	return boxes_win_xp_installer_type_id__volatile;
}


static void _vala_boxes_win_xp_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWinXPInstaller * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIN_XP_INSTALLER, BoxesWinXPInstaller);
	switch (property_id) {
		case BOXES_WIN_XP_INSTALLER_USER_DATA_FOR_VM_CREATION_AVAILABLE:
		g_value_set_boolean (value, boxes_installer_media_get_user_data_for_vm_creation_available ((BoxesInstallerMedia*) self));
		break;
		case BOXES_WIN_XP_INSTALLER_SUPPORTS_VIRTIO_DISK:
		g_value_set_boolean (value, boxes_installer_media_get_supports_virtio_disk ((BoxesInstallerMedia*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



